@@ -2,9 +2,9 @@ package Graphics::Primitive::Driver;
 use Moose::Role;
 
 requires qw(
-    _draw_canvas _draw_component _draw_line _draw_path _draw_rectangle
-    _draw_textbox _do_fill _do_stroke _finish_page _resize data 
-    get_text_bounding_box reset write
+    _draw_canvas _draw_component _draw_line _draw_path _draw_polygon
+    _draw_rectangle _draw_textbox _do_fill _do_stroke _finish_page _resize
+    data get_text_bounding_box reset write
 );
 
 has 'height' => (
